<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="649"/>
        <source>Activate task %1</source>
        <translation>Activa la tasca %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="547"/>
        <source>Application</source>
        <translation>Aplicació</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="581"/>
        <source>To &amp;Desktop</source>
        <translation>A l&apos;&amp;escriptori</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="584"/>
        <source>&amp;All Desktops</source>
        <translation>T&amp;ots els escriptoris</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="594"/>
        <source>Desktop &amp;%1</source>
        <translation>Escriptori &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="604"/>
        <source>&amp;To Current Desktop</source>
        <translation>A l&apos;escriptori ac&amp;tual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="616"/>
        <source>Move To N&amp;ext Monitor</source>
        <translation>Canvia al s&amp;egüent monitor</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="619"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Mou al &amp;monitor anterior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="625"/>
        <source>&amp;Move</source>
        <translation>&amp;Mou</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="630"/>
        <source>Resi&amp;ze</source>
        <translation>Redimen&amp;siona</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="639"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximitza</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="648"/>
        <source>Maximize vertically</source>
        <translation>Maximitza verticalment</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="655"/>
        <source>Maximize horizontally</source>
        <translation>Maximitza horitzontalment</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="663"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaura</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="671"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimitza</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="679"/>
        <source>Roll down</source>
        <translation>Enrotlla cap avall</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="687"/>
        <source>Roll up</source>
        <translation>Enrotlla cap amunt</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="696"/>
        <source>&amp;Layer</source>
        <translation>&amp;Capa</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="701"/>
        <source>Always on &amp;top</source>
        <translation>Sempre a la par&amp;t superior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="706"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="711"/>
        <source>Always on &amp;bottom</source>
        <translation>Sempre a la part in&amp;ferior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="718"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="86"/>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="88"/>
        <source>Close group</source>
        <translation>Tanca el grup</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Ajusts del gestor de tasques</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Mostra únicament les finestres de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Mostra únicament les finestres de la pantalla del &amp;tauler</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Mostra únicament les finestres minimitzades</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Eleva les finestres minimitzades en l&apos;escriptori actual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Tanca amb el clic del botó del mig</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="254"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="264"/>
        <source>Comma separated list of window classes</source>
        <translation>Llista de classes de finestres separades per comes</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="257"/>
        <source>Exclude from taskbar</source>
        <translation>Exclou de la barra de tasques</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Recorre les finestres amb el desplaçament del ratolí</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>A&amp;grupació de les finestres</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Mostra el menú emergent en passar per sobre el ratolí</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Aparença</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Estil del botó</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Amplada màxima del botó</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Roda del ratolí</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Llindar Delta de la roda</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Posa els botons de la mateixa classe un al costat de l&apos;altre</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Alçada màxima del botó</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Gi&amp;ra automàticament els botons quan el tauler sigui vertical</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Utilitza les icones de classe de finestra, si estigués disponible</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Icon and text</source>
        <translation>Icona i text</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only icon</source>
        <translation>Només la icona</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Only text</source>
        <translation>Només el text</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Disabled</source>
        <translation>Inhabilitat</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Desplaça amunt per pujar, avall per minimitzar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Desplaça cap amunt per minimitzar, cap avall per pujar</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="54"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Desplaça amunt per moure&apos;s al següent escriptori, avall a l&apos;anterior</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Desplaça cap amunt per moure&apos;s a l&apos;escriptori anterior, cap avall fins al següent</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="60"/>
        <source>Current</source>
        <translation>Actual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="67"/>
        <source>Desktop %1</source>
        <translation>Escriptori %1</translation>
    </message>
</context>
</TS>
